@@ -29,12 +29,11 @@ parser.add_argument(
 
 def run_csv_job(config_file, output_dir):
     carte_loader = CarteLoader()
-    extractors = parse_config(config_file)
+    extractors, config = parse_config(config_file)
 
     job_config = ConfigFactory.from_dict(
-        {
-            "loader.carte.tables_output_path": output_dir,
-        }
+        {"loader.carte.tables_output_path": output_dir,
+         **config}
     )
 
     for extractor in extractors:
